==> appier_flutter-2.5.0-dev2.tar.gz: lib/appier_flutter.dart <==
import 'dart:async';

import 'package:flutter_inappwebview/flutter_inappwebview.dart';

import 'src/appier_flutter_platform.dart';
import 'data_tracking_config.dart';
import 'src/web_view_support.dart';

class AppierFlutter {
  /// Configures the SDK
  ///
  /// ```
  /// AppierFlutter.configure("APP_ID", senderId: "SENDER_ID",
  /// appGroup: "APP_GROUP", isDev: true);
  /// ```
  /// [senderId] is used in Andriod
  /// [appGroup] is used in iOS. It will help to share data between app target
  /// and extensions. App Group is 'Required' to log events from extension and
  /// also to track certain events from the rich push notification.
  static Future<void> configure(String appId,
      {String? senderId, String? appGroup, bool isDev = false}) async {
    await AppierFlutterPlatform.instance
        .configure(appId, senderId: senderId, appGroup: appGroup, isDev: isDev);
  }

  /// Set Firebase Cloud Messaging token.
  ///
  /// ```
  /// AppierFlutter.setFcmToken("FCM_TOKEN")
  /// ```
  static Future<void> setFcmToken(String token) {
    return AppierFlutterPlatform.instance.setFcmToken(token);
  }

  /// Set the Apple Push Notification service (APNS) token.
  ///
  /// ```
  /// AppierFlutter.setApnsToken("APNS_TOKEN")
  /// ```
  static Future<void> setApnsToken(String token) {
    return AppierFlutterPlatform.instance.setApnsToken(token);
  }

  /// Regenerates `userId`.
  ///
  /// ```
  /// AppierFlutter.renewUserId()
  /// ```
  @Deprecated('use renewAppierId() instead.')
  static Future<void> renewUserId() async {
    await AppierFlutterPlatform.instance.renewAppierId();
  }

  /// Regenerates `appierId`.
  ///
  /// ```
  /// AppierFlutter.renewAppierId()
  /// ```
  static Future<void> renewAppierId() async {
    await AppierFlutterPlatform.instance.renewAppierId();
  }

  /// Get `appierId`.
  ///
  /// ```
  /// AppierFlutter.getAppierId()
  /// ```
  static Future<String> getAppierId() async {
    return AppierFlutterPlatform.instance.getAppierId();
  }

  /// Enables IDFA consent.
  ///
  /// When IDFA consent is enabled, IDFA will only be collected when App Tracking
  /// Transparency (ATT) status is `Authorized`.
  ///
  /// This API only takes effect on iOS platform.
  static Future<void> enableIdfaConsent() {
    return AppierFlutterPlatform.instance.enableIdfaConsent();
  }

  /// Disables IDFA consent.
  ///
  /// When IDFA consent is disabled, IDFA will be collected without checking
  /// App Tracking Transparency (ATT) status. However, depending on the status,
  /// the IDFA collected may be valid or invalid
  /// (e.g. 00000000-0000-0000-0000-000000000000).
  ///
  /// This API only takes effect on iOS platform.
  static Future<void> disableIdfaConsent() {
    return AppierFlutterPlatform.instance.disableIdfaConsent();
  }

  /// Set the Associated Domains for Universal Links
  ///
  /// ```
  /// AppierFlutter.setUniversalLinkDomains(["www.domain.com"])
  /// ```
  /// This is used in iOS
  static Future<void> setUniversalLinkDomains(List<String> linkDomains) async {
    await AppierFlutterPlatform.instance.setUniversalLinkDomains(linkDomains);
  }

  /// Sends any event in your app to the Appier server
  ///
  /// ```
  /// AppierFlutter.logEvent("product_purchased", parameters: { "param1": 2,
  /// "param2": null, "param3": "appier"}, vts: 100, vtsCurr: "USD")
  /// ```
  /// [vts] and [vtsCurr] are optional.
  /// [vts] - valueToSum. It is a monetary value(number) associated to the event
  /// [vtsCurr] - currency code of the value to sum, for example: "USD" or "NTD"
  static Future<void> logEvent(String eventName,
      {Map<String, dynamic>? parameters, double? vts, String? vtsCurr}) async {
    await AppierFlutterPlatform.instance.logEvent(eventName,
        parameters: parameters, vts: vts, vtsCurr: vtsCurr);
  }

  /// Immediately uploads queued data to the Appier server
  ///
  /// ```
  /// AppierFlutter.flush()
  /// ```
  /// By default, queued data is flushed to the Appier servers every 15 seconds
  /// (the default for flushInterval). You only need to call this method
  /// manually if you want to force a flush at a particular moment.
  static Future<void> flush() async {
    await AppierFlutterPlatform.instance.flush();
  }

  /// Set the unique user id for your users
  ///
  /// ```
  /// AppierFlutter.setUserId("2031203056")
  /// ```
  static Future<void> setUserId(String userId) async {
    await AppierFlutterPlatform.instance.setUserId(userId);
  }

  /// Set the name of the user
  ///
  /// ```
  /// AppierFlutter.setName("Gary.Wu")
  /// ```
  static Future<void> setName(String name) async {
    await AppierFlutterPlatform.instance.setName(name);
  }

  /// Set the firstName of the user
  ///
  /// ```
  /// AppierFlutter.setFirstName("Gary")
  /// ```
  static Future<void> setFirstName(String firstName) async {
    await AppierFlutterPlatform.instance.setFirstName(firstName);
  }

  /// Set the lastName of the user
  ///
  /// ```
  /// AppierFlutter.setLastName("Wu")
  /// ````
  static Future<void> setLastName(String lastName) async {
    await AppierFlutterPlatform.instance.setLastName(lastName);
  }

  /// Set the city of the user
  ///
  /// ```
  /// AppierFlutter.setCity("Taipei")
  /// ```
  static Future<void> setCity(String city) async {
    await AppierFlutterPlatform.instance.setCity(city);
  }

  /// Set the email of the user
  ///
  /// ```
  /// AppierFlutter.setEmail("feedback@appier.com")
  /// ```
  static Future<void> setEmail(String email) async {
    await AppierFlutterPlatform.instance.setEmail(email);
  }

  /// Set the phoneNumber of the user
  ///
  /// ```
  /// AppierFlutter.setPhoneNumber("02-8865252")
  /// ```
  static Future<void> setPhoneNumber(String phoneNo) async {
    await AppierFlutterPlatform.instance.setPhoneNumber(phoneNo);
  }

  /// Set the day of DOB of the user
  ///
  /// ```
  /// AppierFlutter.setDayOfBirth(29)
  /// ```
  static Future<void> setDayOfBirth(int day) async {
    await AppierFlutterPlatform.instance.setDayOfBirth(day);
  }

  /// Set the month of DOB of the user
  ///
  /// ```
  /// AppierFlutter.setMonthOfBirth(7)
  /// ````
  static Future<void> setMonthOfBirth(int month) async {
    await AppierFlutterPlatform.instance.setMonthOfBirth(month);
  }

  /// Set the year of DOB of the user
  ///
  /// ```
  /// AppierFlutter.setYearOfBirth(1992)
  /// ```
  static Future<void> setYearOfBirth(int year) async {
    await AppierFlutterPlatform.instance.setYearOfBirth(year);
  }

  /// Set any custom key for your user
  ///
  /// ````
  /// AppierFlutter.setCustomKey("rating", 3.5)
  /// ```
  static Future<void> setCustomKey(String key, dynamic value) async {
    await AppierFlutterPlatform.instance.setCustomKey(key, value);
  }

  /// Sets the View Through Attribution Window for event attribution
  ///
  /// ```
  /// AppierFlutter.setAttributionWindow(10000)
  /// ```
  /// Pass [seconds] as 0 to disable view-through attribution
  static Future<void> setAttributionWindow(int seconds) async {
    await AppierFlutterPlatform.instance.setAttributionWindow(seconds);
  }

  /// Sets the Click Through Attribution Window for event attribution
  ///
  /// ```
  /// AppierFlutter.setClickAttributionWindow(20000)
  /// ```
  /// Pass [seconds] as 0 to disable click attribution
  static Future<void> setClickAttributionWindow(int seconds) async {
    await AppierFlutterPlatform.instance.setClickAttributionWindow(seconds);
  }

  /// Gets recommendation by [scenarioId] with optional [productId] and
  /// [parameters].
  static Future<Map<String, dynamic>?> getRecommendation(String scenarioId,
      {String? productId, Map<String, dynamic>? parameters}) {
    return AppierFlutterPlatform.instance.getRecommendation(scenarioId,
        productId: productId, parameters: parameters);
  }

  /// Logs recommendation clicked by [scenarioId], [modelId], [productId] and
  /// [recommendationId].
  static Future<void> logRecommendationClicked(String scenarioId, int modelId,
      String productId, String recommendationId) {
    return AppierFlutterPlatform.instance.logRecommendationClicked(
        scenarioId, modelId, productId, recommendationId);
  }

  // /* Tag Recommendation is not ready for release
  // /// Gets recommendation popular tags by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationPopularTags(
      Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance
        .getRecommendationPopularTags(parameters);
  }

/*
  /// Gets recommendation product to tags by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationProductToTags(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationProductToTags(parameters);
  }

  /// Gets recommendation tag to tags by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationTagToTags(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationTagToTags(parameters);
  }

  /// Gets recommendation user to tags by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationUserToTags(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationUserToTags(parameters);
  }

  /// Gets recommendation tag to products by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationTagToProducts(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationTagToProducts(parameters);
  }
  */

  /// Eanbles Web SDK bridge to web views.
  ///
  /// Pass [inAppWebViewController] to enable it with `InAppWebView` from
  /// `flutter_inappwebview`.
  static Future<void> enableWebSdkBridge(
      {InAppWebViewController? inAppWebViewController}) async {
    if (inAppWebViewController != null) {
      await InAppWebViewBridge(inAppWebViewController).install();
    }
  }

  /// Send the remote message string [messageString] to AIQUA
  static Future<void> handleRemoteMessage(String messageString) async {
    return AppierFlutterPlatform.instance.handleRemoteMessage(messageString);
  }

  /// Check if the remote message is from AIQUA
  static Future<bool> isAppierPush(String messageString) async {
    return AppierFlutterPlatform.instance.isAppierPush(messageString);
  }

  /// Hide the in-app campaigns
  static Future<void> hideInAppCampaigns() {
    return AppierFlutterPlatform.instance.hideInAppCampaigns();
  }

  /// Enable stored notifications
  static Future<void> enableStoredNotifications() async {
    await AppierFlutterPlatform.instance.enableStoredNotifications();
  }

  /// Get stored notifications
  static Future<List<Map<String, dynamic>>> getStoredNotifications() async {
    return AppierFlutterPlatform.instance.getStoredNotifications();
  }

  /// Set stored notifications limit
  static Future<void> setStoredNotificationsLimit(int limit) async {
    await AppierFlutterPlatform.instance.setStoredNotificationsLimit(limit);
  }

  /// Delete all stored notifications
  static Future<void> deleteAllStoredNotifications() async {
    await AppierFlutterPlatform.instance.deleteAllStoredNotifications();
  }

  /// Delete stored notifications at index
  static Future<void> deleteStoredNotification(int index) async {
    print('deleteStoredNotification $index - appier_flutter.dart');
    await AppierFlutterPlatform.instance.deleteStoredNotification(index);
  }

  static Future<DataTrackingConfig> getDataTrackingConfig() async {
    return AppierFlutterPlatform.instance.getDataTrackingConfig();
  }

  static Future<void> setDataTrackingConfig(DataTrackingConfig config) async {
    await AppierFlutterPlatform.instance.setDataTrackingConfig(config);
  }
}

==> appier_flutter-2.6.0-dev.1.tar.gz: lib/appier_flutter.dart <==
import 'dart:async';

import 'package:flutter_inappwebview/flutter_inappwebview.dart';

import 'src/appier_flutter_platform.dart';
import 'data_tracking_config.dart';
import 'src/web_view_support.dart';

class AppierFlutter {
  /// Configures the SDK
  ///
  /// ```
  /// AppierFlutter.configure("APP_ID", senderId: "SENDER_ID",
  /// appGroup: "APP_GROUP", isDev: true);
  /// ```
  /// [senderId] is used in Andriod
  /// [appGroup] is used in iOS. It will help to share data between app target
  /// and extensions. App Group is 'Required' to log events from extension and
  /// also to track certain events from the rich push notification.
  static Future<void> configure(String appId,
      {String? senderId, String? appGroup, bool isDev = false}) async {
    await AppierFlutterPlatform.instance
        .configure(appId, senderId: senderId, appGroup: appGroup, isDev: isDev);
  }

  /// Set Firebase Cloud Messaging token.
  ///
  /// ```
  /// AppierFlutter.setFcmToken("FCM_TOKEN")
  /// ```
  static Future<void> setFcmToken(String token) {
    return AppierFlutterPlatform.instance.setFcmToken(token);
  }

  /// Set the Apple Push Notification service (APNS) token.
  ///
  /// ```
  /// AppierFlutter.setApnsToken("APNS_TOKEN")
  /// ```
  static Future<void> setApnsToken(String token) {
    return AppierFlutterPlatform.instance.setApnsToken(token);
  }

  /// Regenerates `userId`.
  ///
  /// ```
  /// AppierFlutter.renewUserId()
  /// ```
  @Deprecated('use renewAppierId() instead.')
  static Future<void> renewUserId() async {
    await AppierFlutterPlatform.instance.renewAppierId();
  }

  /// Regenerates `appierId`.
  ///
  /// ```
  /// AppierFlutter.renewAppierId()
  /// ```
  static Future<void> renewAppierId() async {
    await AppierFlutterPlatform.instance.renewAppierId();
  }

  /// Get `appierId`.
  ///
  /// ```
  /// AppierFlutter.getAppierId()
  /// ```
  static Future<String> getAppierId() async {
    return AppierFlutterPlatform.instance.getAppierId();
  }

  /// Enables IDFA consent.
  ///
  /// When IDFA consent is enabled, IDFA will only be collected when App Tracking
  /// Transparency (ATT) status is `Authorized`.
  ///
  /// This API only takes effect on iOS platform.
  static Future<void> enableIdfaConsent() {
    return AppierFlutterPlatform.instance.enableIdfaConsent();
  }

  /// Disables IDFA consent.
  ///
  /// When IDFA consent is disabled, IDFA will be collected without checking
  /// App Tracking Transparency (ATT) status. However, depending on the status,
  /// the IDFA collected may be valid or invalid
  /// (e.g. 00000000-0000-0000-0000-000000000000).
  ///
  /// This API only takes effect on iOS platform.
  static Future<void> disableIdfaConsent() {
    return AppierFlutterPlatform.instance.disableIdfaConsent();
  }

  /// Set the Associated Domains for Universal Links
  ///
  /// ```
  /// AppierFlutter.setUniversalLinkDomains(["www.domain.com"])
  /// ```
  /// This is used in iOS
  static Future<void> setUniversalLinkDomains(List<String> linkDomains) async {
    await AppierFlutterPlatform.instance.setUniversalLinkDomains(linkDomains);
  }

  /// Sends any event in your app to the Appier server
  ///
  /// ```
  /// AppierFlutter.logEvent("product_purchased", parameters: { "param1": 2,
  /// "param2": null, "param3": "appier"}, vts: 100, vtsCurr: "USD")
  /// ```
  /// [vts] and [vtsCurr] are optional.
  /// [vts] - valueToSum. It is a monetary value(number) associated to the event
  /// [vtsCurr] - currency code of the value to sum, for example: "USD" or "NTD"
  static Future<void> logEvent(String eventName,
      {Map<String, dynamic>? parameters, double? vts, String? vtsCurr}) async {
    await AppierFlutterPlatform.instance.logEvent(eventName,
        parameters: parameters, vts: vts, vtsCurr: vtsCurr);
  }

  /// Immediately uploads queued data to the Appier server
  ///
  /// ```
  /// AppierFlutter.flush()
  /// ```
  /// By default, queued data is flushed to the Appier servers every 15 seconds
  /// (the default for flushInterval). You only need to call this method
  /// manually if you want to force a flush at a particular moment.
  static Future<void> flush() async {
    await AppierFlutterPlatform.instance.flush();
  }

  /// Set the unique user id for your users
  ///
  /// ```
  /// AppierFlutter.setUserId("2031203056")
  /// ```
  static Future<void> setUserId(String userId) async {
    await AppierFlutterPlatform.instance.setUserId(userId);
  }

  /// Set the name of the user
  ///
  /// ```
  /// AppierFlutter.setName("Gary.Wu")
  /// ```
  static Future<void> setName(String name) async {
    await AppierFlutterPlatform.instance.setName(name);
  }

  /// Set the firstName of the user
  ///
  /// ```
  /// AppierFlutter.setFirstName("Gary")
  /// ```
  static Future<void> setFirstName(String firstName) async {
    await AppierFlutterPlatform.instance.setFirstName(firstName);
  }

  /// Set the lastName of the user
  ///
  /// ```
  /// AppierFlutter.setLastName("Wu")
  /// ````
  static Future<void> setLastName(String lastName) async {
    await AppierFlutterPlatform.instance.setLastName(lastName);
  }

  /// Set the city of the user
  ///
  /// ```
  /// AppierFlutter.setCity("Taipei")
  /// ```
  static Future<void> setCity(String city) async {
    await AppierFlutterPlatform.instance.setCity(city);
  }

  /// Set the email of the user
  ///
  /// ```
  /// AppierFlutter.setEmail("feedback@appier.com")
  /// ```
  static Future<void> setEmail(String email) async {
    await AppierFlutterPlatform.instance.setEmail(email);
  }

  /// Set the phoneNumber of the user
  ///
  /// ```
  /// AppierFlutter.setPhoneNumber("02-8865252")
  /// ```
  static Future<void> setPhoneNumber(String phoneNo) async {
    await AppierFlutterPlatform.instance.setPhoneNumber(phoneNo);
  }

  /// Set the day of DOB of the user
  ///
  /// ```
  /// AppierFlutter.setDayOfBirth(29)
  /// ```
  static Future<void> setDayOfBirth(int day) async {
    await AppierFlutterPlatform.instance.setDayOfBirth(day);
  }

  /// Set the month of DOB of the user
  ///
  /// ```
  /// AppierFlutter.setMonthOfBirth(7)
  /// ````
  static Future<void> setMonthOfBirth(int month) async {
    await AppierFlutterPlatform.instance.setMonthOfBirth(month);
  }

  /// Set the year of DOB of the user
  ///
  /// ```
  /// AppierFlutter.setYearOfBirth(1992)
  /// ```
  static Future<void> setYearOfBirth(int year) async {
    await AppierFlutterPlatform.instance.setYearOfBirth(year);
  }

  /// Set any custom key for your user
  ///
  /// ````
  /// AppierFlutter.setCustomKey("rating", 3.5)
  /// ```
  static Future<void> setCustomKey(String key, dynamic value) async {
    await AppierFlutterPlatform.instance.setCustomKey(key, value);
  }

  /// Sets the View Through Attribution Window for event attribution
  ///
  /// ```
  /// AppierFlutter.setAttributionWindow(10000)
  /// ```
  /// Pass [seconds] as 0 to disable view-through attribution
  static Future<void> setAttributionWindow(int seconds) async {
    await AppierFlutterPlatform.instance.setAttributionWindow(seconds);
  }

  /// Sets the Click Through Attribution Window for event attribution
  ///
  /// ```
  /// AppierFlutter.setClickAttributionWindow(20000)
  /// ```
  /// Pass [seconds] as 0 to disable click attribution
  static Future<void> setClickAttributionWindow(int seconds) async {
    await AppierFlutterPlatform.instance.setClickAttributionWindow(seconds);
  }

  /// Gets recommendation by [scenarioId] with optional [productId] and
  /// [parameters].
  static Future<Map<String, dynamic>?> getRecommendation(String scenarioId,
      {String? productId, Map<String, dynamic>? parameters}) {
    return AppierFlutterPlatform.instance.getRecommendation(scenarioId,
        productId: productId, parameters: parameters);
  }

  /// Logs recommendation clicked by [scenarioId], [modelId], [productId] and
  /// [recommendationId].
  static Future<void> logRecommendationClicked(String scenarioId, int modelId,
      String productId, String recommendationId) {
    return AppierFlutterPlatform.instance.logRecommendationClicked(
        scenarioId, modelId, productId, recommendationId);
  }

  /* Tag Recommendation is not ready for release
  /// Gets recommendation popular tags by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationPopularTags(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationPopularTags(parameters);
  }

  /// Gets recommendation product to tags by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationProductToTags(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationProductToTags(parameters);
  }

  /// Gets recommendation tag to tags by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationTagToTags(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationTagToTags(parameters);
  }

  /// Gets recommendation user to tags by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationUserToTags(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationUserToTags(parameters);
  }

  /// Gets recommendation tag to products by [parameters].
  static Future<Map<String, dynamic>?> getRecommendationTagToProducts(Map<String, dynamic>? parameters) {
    return AppierFlutterPlatform.instance.getRecommendationTagToProducts(parameters);
  }
  */

  /// Eanbles Web SDK bridge to web views.
  ///
  /// Pass [inAppWebViewController] to enable it with `InAppWebView` from
  /// `flutter_inappwebview`.
  static Future<void> enableWebSdkBridge(
      {InAppWebViewController? inAppWebViewController}) async {
    if (inAppWebViewController != null) {
      await InAppWebViewBridge(inAppWebViewController).install();
    }
  }

  /// Send the remote message string [messageString] to AIQUA
  static Future<void> handleRemoteMessage(String messageString) async {
    return AppierFlutterPlatform.instance.handleRemoteMessage(messageString);
  }

  /// Check if the remote message is from AIQUA
  static Future<bool> isAppierPush(String messageString) async {
    return AppierFlutterPlatform.instance.isAppierPush(messageString);
  }

  /// Hide the in-app campaigns
  static Future<void> hideInAppCampaigns() {
    return AppierFlutterPlatform.instance.hideInAppCampaigns();
  }

  /// Enable stored notifications
  static Future<void> enableStoredNotifications() async {
    await AppierFlutterPlatform.instance.enableStoredNotifications();
  }

  /// Get stored notifications
  static Future<List<Map<String, dynamic>>> getStoredNotifications() async {
    return AppierFlutterPlatform.instance.getStoredNotifications();
  }

  /// Set stored notifications limit
  static Future<void> setStoredNotificationsLimit(int limit) async {
    await AppierFlutterPlatform.instance.setStoredNotificationsLimit(limit);
  }

  /// Delete all stored notifications
  static Future<void> deleteAllStoredNotifications() async {
    await AppierFlutterPlatform.instance.deleteAllStoredNotifications();
  }

  /// Delete stored notifications at index
  static Future<void> deleteStoredNotification(int index) async {
    print('deleteStoredNotification $index - appier_flutter.dart');
    await AppierFlutterPlatform.instance.deleteStoredNotification(index);
  }

  static Future<DataTrackingConfig> getDataTrackingConfig() async {
    return AppierFlutterPlatform.instance.getDataTrackingConfig();
  }

  static Future<void> setDataTrackingConfig(DataTrackingConfig config) async {
    await AppierFlutterPlatform.instance.setDataTrackingConfig(config);
  }
}
